@@ -8,7 +8,7 @@ use base qw{ Exporter };
 # CAVEAT: do not include any other PPIx-Regexp modules in this one, or
 # you will end up with a circular dependency.
 
-our $VERSION = '0.068';
+our $VERSION = '0.074';
 
 our @EXPORT_OK = qw{
     ARRAY_REF
@@ -24,6 +24,11 @@ our @EXPORT_OK = qw{
     LITERAL_LEFT_CURLY_REMOVED_PHASE_1
     LITERAL_LEFT_CURLY_REMOVED_PHASE_2
     LITERAL_LEFT_CURLY_REMOVED_PHASE_3
+    LOCATION_LINE
+    LOCATION_CHARACTER
+    LOCATION_COLUMN
+    LOCATION_LOGICAL_LINE
+    LOCATION_LOGICAL_FILE
     MINIMUM_PERL
     MODIFIER_GROUP_MATCH_SEMANTICS
     MSG_PROHIBITED_BY_STRICT
@@ -48,7 +53,6 @@ our @CARP_NOT = qw{
     PPIx::Regexp::Node
     PPIx::Regexp::Node::Range
     PPIx::Regexp::Node::Unknown
-    PPIx::Regexp::StringTokenizer
     PPIx::Regexp::Structure
     PPIx::Regexp::Structure::Assertion
     PPIx::Regexp::Structure::Atomic_Script_Run
@@ -141,6 +145,13 @@ use constant LITERAL_LEFT_CURLY_REMOVED_PHASE_2	=> undef;	# x{ 5.30
 # there.
 use constant LITERAL_LEFT_CURLY_REMOVED_PHASE_3	=> undef;	# ({ 5.32
 
+# Location constants. Must align with PPI
+use constant LOCATION_LINE         => 0;
+use constant LOCATION_CHARACTER    => 1;
+use constant LOCATION_COLUMN       => 2;
+use constant LOCATION_LOGICAL_LINE => 3;
+use constant LOCATION_LOGICAL_FILE => 4;
+
 use constant MINIMUM_PERL	=> '5.000';
 
 use constant MODIFIER_GROUP_MATCH_SEMANTICS => 'match_semantics';
