@@ -53,7 +53,7 @@ use base qw{PPIx::Regexp::Element};
 use Carp qw{ confess };
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL @CARP_NOT };
 
-our $VERSION = '0.065';
+our $VERSION = '0.074';
 
 use constant TOKENIZER_ARGUMENT_REQUIRED => 0;
 
@@ -68,7 +68,9 @@ sub __new {
 	content => $content,
     };
 
-    foreach my $key ( qw{ perl_version_introduced perl_version_removed } ) {
+    foreach my $key ( qw{
+	    explanation perl_version_introduced perl_version_removed
+	} ) {
 	defined $arg{$key}
 	    and $self->{$key} = $arg{$key};
     }
@@ -82,6 +84,28 @@ sub content {
     return $self->{content};
 }
 
+=head2 first_token
+
+This method returns its invocant.
+
+=cut
+
+sub first_token {
+    my ( $self ) = @_;
+    return $self;
+}
+
+=head2 last_token
+
+This method returns its invocant.
+
+=cut
+
+sub last_token {
+    my ( $self ) = @_;
+    return $self;
+}
+
 sub perl_version_introduced {
     my ( $self ) = @_;
     return defined $self->{perl_version_introduced} ?
@@ -122,7 +146,7 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -130,7 +154,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2019 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
