@@ -41,7 +41,7 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.068';
+our $VERSION = '0.074';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -60,6 +60,15 @@ our $VERSION = '0.068';
 ##    return;
 ##}
 
+=head2 is_matcher
+
+This method returns a true value because a character class actually
+matches something.
+
+=cut
+
+sub is_matcher { return 1; }
+
 1;
 
 __END__
